@@ -10,14 +10,15 @@ from code_loader.contract.datasetclasses import SectionCallableInterface, InputH
     MetadataSectionCallableInterface, UnlabeledDataPreprocessHandler, CustomLayerHandler, MetricHandler, \
     CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs, LeapData, \
     CustomMultipleReturnCallableInterfaceMultiArgs, DatasetBaseHandler, custom_latent_space_attribute, \
-    RawInputsForHeatmap, VisualizerHandlerData, MetricHandlerData, CustomLossHandlerData, SamplePreprocessResponse
+    RawInputsForHeatmap, VisualizerHandlerData, MetricHandlerData, CustomLossHandlerData, SamplePreprocessResponse, \
+    ElementInstanceMasksHandler, InstanceCallableInterface
 from code_loader.contract.enums import LeapDataType, DataStateEnum, DataStateType, MetricDirection, DatasetMetadataType
 from code_loader.contract.mapping import NodeConnection, NodeMapping, NodeMappingType
 from code_loader.contract.responsedataclasses import DatasetTestResultPayload
 from code_loader.contract.visualizer_classes import map_leap_data_type_to_visualizer_class
 from code_loader.default_losses import loss_name_to_function
 from code_loader.default_metrics import metrics_names_to_functions_and_direction
-from code_loader.utils import to_numpy_return_wrapper, get_shape
+from code_loader.utils import to_numpy_return_wrapper, get_shape, to_numpy_return_masks_wrapper
 from code_loader.visualizers.default_visualizers import DefaultVisualizer, \
     default_graph_visualizer, \
     default_image_visualizer, default_horizontal_bar_visualizer, default_word_visualizer, \
@@ -234,6 +235,22 @@ class LeapBinder:
 
         self._encoder_names.append(name)
 
+
+    def set_instance_masks(self, function: InstanceCallableInterface, name: str) -> None:
+        """
+        Set the instance mask handler function.
+
+        Args:
+        function (SectionCallableInterface): The input handler function.
+        name (str): The name of the instance mask section.
+
+        Example:
+            leap_binder.set_input(input_encoder, name='input_encoder')
+        """
+        function = to_numpy_return_masks_wrapper(function)
+        self.setup_container.instance_masks.append(ElementInstanceMasksHandler(name, function))
+
+
     def add_custom_loss(self, function: CustomCallableInterface, name: str) -> None:
         """
         Add a custom loss function to the setup.
@@ -513,9 +530,10 @@ class LeapBinder:
                 for i, (single_metadata_name, single_metadata_result) in enumerate(raw_result.items()):
                     metadata_test_result = metadata_test_result_payloads[i]
 
-                    if not isinstance(single_metadata_result, (int, str, bool, float, np.unsignedinteger, np.signedinteger, np.bool_, np.floating)):
+                    if not isinstance(single_metadata_result, (int, str, bool, float, np.unsignedinteger,
+                                                               np.signedinteger, np.bool_, np.floating, type(None))):
                         raise Exception(f"Unsupported return type of metadata {single_metadata_name}."
-                                        f"The return type should be one of [int, float, str, bool]. Got {type(single_metadata_result)}")
+                                        f"The return type should be one of [int, float, str, bool, None]. Got {type(single_metadata_result)}")
 
                     metadata_type = None
                     if single_metadata_result is None:
